@@ -492,7 +492,7 @@ int main(int argc, char **argv)
 			startas = optarg;
 			break;
 		case 'w':
-			if (sscanf(optarg, "%d", &start_wait) != 1)
+			if (sscanf(optarg, "%u", &start_wait) != 1)
 				eerrorx("%s: `%s' not a number",
 				    applet, optarg);
 			break;
@@ -547,7 +547,7 @@ int main(int argc, char **argv)
 	} else if (name) {
 		*--argv = name;
 		++argc;
-    } else if (exec) {
+	} else if (exec) {
 		*--argv = exec;
 		++argc;
 	};
